summaryrefslogtreecommitdiff
path: root/alot/db/envelope.py
diff options
context:
space:
mode:
authorPatrick Totzke <patricktotzke@gmail.com>2012-03-11 18:43:41 +0000
committerPatrick Totzke <patricktotzke@gmail.com>2012-03-11 18:43:41 +0000
commit9d513123cdc50608208200c77052db58fbb8619a (patch)
tree91e08a07dd63620dadfcdcbb346a3541a5162f6c /alot/db/envelope.py
parent349654f4e62eb77754f08351bf3fb51fbe6d8f7c (diff)
refactor: Attachment in its own file
Diffstat (limited to 'alot/db/envelope.py')
-rw-r--r--alot/db/envelope.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/alot/db/envelope.py b/alot/db/envelope.py
index 4af1a05b..6572b507 100644
--- a/alot/db/envelope.py
+++ b/alot/db/envelope.py
@@ -11,7 +11,7 @@ import logging
import alot.helper as helper
from alot.settings import settings
-from message import Attachment
+from attachment import Attachment
from message import encode_header
@@ -29,7 +29,7 @@ class Envelope(object):
:param headers: unencoded header values
:type headers: dict (str -> unicode)
:param attachments: file attachments to include
:type attachments: list of :class:`Attachment`
"""
assert isinstance(bodytext, unicode)
self.headers = {}
@@ -107,11 +107,11 @@ class Envelope(object):
"""
attach a file
- :param attachment: File to attach, given as :class:`Attachment` object
- or path to a file.
- :type attachment: :class:`Attachment` or str
+ :param attachment: File to attach, given as
+ :class:`~alot.db.attachment.Attachment` object or path to a file.
+ :type attachment: :class:`~alot.db.attachment.Attachment` or str
:param filename: filename to use in content-disposition.
- Will be ignored if `path` matches multiple files
+ Will be ignored if `path` matches multiple files
:param ctype: force content-type to be used for this attachment
:type ctype: str
"""
@@ -29,7 +29,7 @@ class Envelope(object):
:type headers: dict (str -> unicode)
:param attachments: file attachments to include
- :type attachments: list of :class:`Attachment`
+ :type attachments: list of :class:`~alot.db.attachment.Attachment`
"""
assert isinstance(bodytext, unicode)